==> openturns_0.12.2.orig.tar.gz: openturns-0.12.2/lib/test/t_ComputedNumericalMathEvaluationImplementationFactory_std.cxx <==
//                                               -*- C++ -*-
/**
 * @file  t_ComputedNumericalMathEvaluationImplementationFactory_std.cxx
 * @brief The test file of class ComputedNumericalMathEvaluationImplementationFactory for standard methods
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-06-26 13:50:17 +0200 (jeu 26 jun 2008) $
 *  Id:      $Id: t_ComputedNumericalMathEvaluationImplementationFactory_std.cxx 862 2008-06-26 11:50:17Z dutka $
 */

#include <iostream>
#include <sstream>
#include <fstream>
#include <iomanip>
#include <string>
#include "OT.hxx"
#include "OTtestcode.hxx"
#include "ComputedNumericalMathEvaluationImplementationFactory.hxx"

using namespace OT;
using namespace OT::Test;
using namespace OT::Base::Func;

int main(int argc, char *argv[])
{
  TESTPREAMBLE;

  showClassName<ComputedNumericalMathEvaluationImplementationFactory>();

  /** Instance creation */
  ComputedNumericalMathEvaluationImplementationFactory::Instance instance = ComputedNumericalMathEvaluationImplementationFactory::getInstance();

  std::cout << (*instance) << std::endl;

  return ExitCode::Success;
}

==> openturns_0.13.1.orig.tar.gz: openturns-0.13.1/lib/test/t_ComputedNumericalMathEvaluationImplementationFactory_std.cxx <==
//                                               -*- C++ -*-
/**
 * @file  t_ComputedNumericalMathEvaluationImplementationFactory_std.cxx
 * @brief The test file of class ComputedNumericalMathEvaluationImplementationFactory for standard methods
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2009-05-28 14:47:53 +0200 (jeu. 28 mai 2009) $
 *  Id:      $Id: t_ComputedNumericalMathEvaluationImplementationFactory_std.cxx 1262 2009-05-28 12:47:53Z dutka $
 */

#include <iostream>
#include <sstream>
#include <fstream>
#include <iomanip>
#include <string>
#include "OT.hxx"
#include "OTtestcode.hxx"
#include "OStream.hxx"
#include "ComputedNumericalMathEvaluationImplementationFactory.hxx"

using namespace OT;
using namespace OT::Test;
using namespace OT::Base::Common;
using namespace OT::Base::Func;

int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);

  showClassName<ComputedNumericalMathEvaluationImplementationFactory>();

  /** Instance creation */
  ComputedNumericalMathEvaluationImplementationFactory::Instance instance = ComputedNumericalMathEvaluationImplementationFactory::getInstance();

  fullprint << (*instance) << std::endl;

  return ExitCode::Success;
}
